---
title: <span class="badge object-type-scalar"></span> PacketsPerSecond
---
# <span class="badge object-type-scalar"></span> PacketsPerSecond

Data rate: packets/sec

## Definition

```python
# Data rate: packets/sec
PacketsPerSecond: typing.Literal["pps"] = "pps"
```
